@@ -1263,7 +1263,7 @@ class DataVars(SimpleDataVars):
         return False
 
     def Select(self,selField,where="os_disk_dev",eq=None,ne=None,
-               _in=None,like=None,notlike=None,func=None,
+               _in=None,_notin=None,like=None,notlike=None,func=None,
                sort=None, sortkey=None, limit=None,zipVars=None):
         """Select value from table variables"""
         if zipVars is None:
@@ -1276,6 +1276,8 @@ class DataVars(SimpleDataVars):
             filterFunc = lambda x:x[0] != ne
         elif _in != None:
             filterFunc = lambda x:x[0] in _in
+        elif _notin != None:
+            filterFunc = lambda x:not x[0] in _notin
         elif like != None:
             filterFunc = lambda x:re.compile(like).search(x[0])
         elif notlike != None:
