@@ -794,3 +794,18 @@ def tarLinks(rootpath,archpath,skip=[]):
         removeDirs)
     tar.close()
     return links
+
+def getch():
+    """
+    Get char from keyboard
+    """
+    import sys, tty, termios
+
+    fd = sys.stdin.fileno()
+    old_settings = termios.tcgetattr(fd)
+    try:
+        tty.setraw(sys.stdin.fileno())
+        ch = sys.stdin.read(1)
+    finally:
+        termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
+    return ch
