@@ -222,6 +222,14 @@ def getMac(iface):
     sockfd.close()
     return ":".join(['%02X' % i for i in mac])
 
+def getOperState(iface):
+    """
+    Get interface state up or down
+    """
+    if readFile("/sys/class/net/%s/operstate"%iface) == "down":
+        return "down"
+    return "up"
+
 def isOpenPort(ip,port):
     """
     Test if an [ip:port] is open
